HitTestMetrics

Struct HitTestMetrics 

#[repr(C)]
pub struct HitTestMetrics { pub text_position: u32, pub length: u32, pub left: f32, pub top: f32, pub width: f32, pub height: f32, pub bidi_level: u32, pub is_text: bool, pub is_trimmed: bool, }
Available on Windows only.
Describes the region obtained by a hit test.

Fields

text_position: u32

The first text position within the hit region.

length: u32

The number of text positions within the hit region.

left: f32

The x-coordinate of the upper-left corner of the hit region.

top: f32

The y-coordinate of the upper-left corner of the hit region.

width: f32

The width of the hit region.

height: f32

The height of the hit region.

bidi_level: u32

The BIDI level of the text positions within the hit region.

is_text: bool

Non-zero if the hit region contains text; otherwise, 0.

is_trimmed: bool

Non-zero if the text range is trimmed; otherwise, 0.