pub struct HitTestPoint {
pub metrics: HitTestMetrics,
pub is_inside: bool,
pub is_trailing_hit: bool,
}Available on Windows only.
Results from calling hit_test_point on a TextLayout.
Fields
metrics: HitTestMetricsThe output geometry fully enclosing the hit-test location. When is_inside is set to false, this structure represents the geometry enclosing the edge closest to the hit-test location.
is_inside: boolAn output flag that indicates whether the hit-test location is inside the text string. When false, the position nearest the text’s edge is returned.
is_trailing_hit: boolAn output flag that indicates whether the hit-test location is at the leading or the trailing side of the character. When is_inside is set to false, this value is set according to the output hitTestMetrics->textPosition value to represent the edge closest to the hit-test location.