pub struct HitTestTextPosition {
pub point_x: f32,
pub point_y: f32,
pub metrics: HitTestMetrics,
}Available on Windows only.
Results from calling hit_test_text_position on a TextLayout.
Fields
point_x: f32The output pixel location X, relative to the top-left location of the layout box.
point_y: f32The output pixel location Y, relative to the top-left location of the layout box.
metrics: HitTestMetricsThe output geometry fully enclosing the specified text position.