pub struct TextLayout(/* private fields */);Available on Windows only.
Implementations
Sourceimpl TextLayout
impl TextLayout
Sourcepub fn get_line_metrics(&self, buf: &mut Vec<DWRITE_LINE_METRICS>)
pub fn get_line_metrics(&self, buf: &mut Vec<DWRITE_LINE_METRICS>)
Get line metrics, storing them in the provided buffer.
Note: this isn’t necessarily the lowest level wrapping, as it requires an allocation for the buffer. But it’s pretty ergonomic.
pub fn get_raw(&self) -> *mut IDWriteTextLayout
pub fn get_metrics(&self) -> DWRITE_TEXT_METRICS
Sourcepub fn get_overhang_metrics(&self) -> Insets
pub fn get_overhang_metrics(&self) -> Insets
Return the DWRITE_OVERHANG_METRICS, converted to an Insets struct.
The ‘right’ and ‘bottom’ values of this struct are relative to the layout width and height; that is, the width and height constraints used to create the layout, not the actual size of the generated layout.
pub fn set_max_width(&mut self, max_width: f64) -> Result<(), Error>
pub fn hit_test_point(&self, point_x: f32, point_y: f32) -> HitTestPoint
pub fn hit_test_text_position( &self, position: u32, trailing: bool, ) -> Option<HitTestTextPosition>